{% if presence %}
{% for cursor in presence %}
<div class="flex items-center gap-1.5 text-xs">
    <span class="presence-dot"></span>
    <span class="opacity-70">{{ cursor.agent_name }}</span>
</div>
{% endfor %}
{% else %}
{# Hide "0 online" for cleaner UI - div remains for HTMX polling #}
{% endif %}
